@@ -1,10 +1,11 @@
-setMethod("t", signature(x = "dtCMatrix"),
-          function(x) {
-              tg <- .Call(csc_transpose, x)
-              new("dtCMatrix", Dim = tg@Dim, Dimnames = x@Dimnames[2:1],
-                  p = tg@p, i = tg@i, x = tg@x, diag = x@diag,
-                  uplo = ifelse(x@uplo == "U", "L", "U"))
-          }, valueClass = "dtCMatrix")
+## can use the method for x = "CsparseMatrix" in ./Csparse.R
+## setMethod("t", signature(x = "dtCMatrix"),
+##           function(x) {
+##               tg <- .Call(csc_transpose, x)
+##               new("dtCMatrix", Dim = tg@Dim, Dimnames = x@Dimnames[2:1],
+##                   p = tg@p, i = tg@i, x = tg@x, diag = x@diag,
+##                   uplo = ifelse(x@uplo == "U", "L", "U"))
+##           }, valueClass = "dtCMatrix")
 
 setAs("dtCMatrix", "ltCMatrix", # just drop 'x' slot:
       function(from) new("ltCMatrix", i = from@i, p = from@p,
@@ -42,18 +43,19 @@ setAs("dtCMatrix", "dgeMatrix",
 setAs("dtCMatrix", "dtTMatrix",
       function(from) {# and this is not elegant:
           x <- as(from, "dgTMatrix")
-	  if (from@diag == "U") { ## drop diagonal entries '1':
-	      i <- x@i; j <- x@j
-	      nonD <- i != j
-	      xx <- x@x[nonD] ; i <- i[nonD] ; j <- j[nonD]
-	  } else {
-	      xx <- x@x; i <- x@i; j <- x@j
-	  }
-	  new("dtTMatrix", x = xx, i = i, j = j, Dim = x@Dim,
-	      Dimnames = x@Dimnames, uplo = from@uplo, diag = from@diag)
+ 	  if (from@diag == "U") { ## drop diagonal entries '1':
+ 	      i <- x@i; j <- x@j
+ 	      nonD <- i != j
+ 	      xx <- x@x[nonD] ; i <- i[nonD] ; j <- j[nonD]
+ 	  } else {
+ 	      xx <- x@x; i <- x@i; j <- x@j
+ 	  }
+ 	  new("dtTMatrix", x = xx, i = i, j = j, Dim = x@Dim,
+ 	      Dimnames = x@Dimnames, uplo = from@uplo, diag = from@diag)
       })
 
-setAs("dtCMatrix", "TsparseMatrix", function(from) as(from, "dtTMatrix"))
+## Now that we support triangular matrices use the inherited method.
+## setAs("dtCMatrix", "TsparseMatrix", function(from) as(from, "dtTMatrix"))
 
 setAs("dtCMatrix", "dtrMatrix",
       function(from) as(as(from, "dtTMatrix"), "dtrMatrix"))
